<?php
add_action( 'after_setup_theme', 'urban_square_setup' );

// define constants to be reused
define( 'TEMPLATE_DIR_URI', get_template_directory_uri() ); // calls template directory from the theme's top level folder
define( "STYLESHEET_DIR", get_stylesheet_directory() ); // calls stylesheet directory from the server's top level folder

function urban_square_setup() {

load_theme_textdomain( 'urban-square', get_template_directory() . '/languages' );

add_theme_support( 'automatic-feed-links' );

add_theme_support( 'post-thumbnails' );

global $content_width;
if ( ! isset( $content_width ) ) $content_width = 640;

register_nav_menus(
array( 'main-menu' => __( 'Main Menu', 'urban-square' ) )
);

/* remove inline styling in gallery code when a gallery is displayed, so the code validates */
add_filter( 'use_default_gallery_style', '__return_false' );
}

/* filter the body class tag to conditionally load .desktop class */
function urban_square_bodyclass_names( $classes ) {
	// if we are not in a mobile environment
	if ( !wp_is_mobile() ) {
		// add 'desktop' to the $classes array
		$classes[] = 'desktop';
		return $classes;
	} else {
		return $classes;
	}
}

add_filter( 'body_class', 'urban_square_bodyclass_names' );

/* Custom Background */
$args = array(
	'default-color' => '#ffffff'
);

add_theme_support( 'custom-background', $args );

/* Custom Header */

$args = array(
	'default-image' => '',
	'width' => get_theme_support( 'custom-header', 'width' ),
	'height' => get_theme_support( 'custom-header', 'height' ),
	'uploads' => true,
	'header-text' => true,
	'default-text-color' => '800000'
);

add_theme_support( 'custom-header', $args );

// Urban Square Customizer additions; found in /options folder
include ( STYLESHEET_DIR . '/options/urban_square_customizer.php');

include ( STYLESHEET_DIR . '/options/urban_square_customizer-frontend.php' );

include ( STYLESHEET_DIR . '/options/urban_square_hidef_images.php' );

add_action( 'wp_enqueue_scripts', 'urban_square_load_scripts' );
function urban_square_load_scripts() {
	wp_enqueue_style( 'urban-square-main-stylesheet', get_stylesheet_uri() );
	wp_enqueue_style( 'urban-square-css3-extensions', TEMPLATE_DIR_URI . '/css3-extensions.css' );
	wp_enqueue_script( 'urban-square-scripts', TEMPLATE_DIR_URI . '/scripts/urban-square-scripts.js', array( 'jquery' ), '1.0', false );
	wp_enqueue_script( 'urban-square-gallery-nobr', TEMPLATE_DIR_URI . '/scripts/gallery-nobr.js', array( 'jquery' ), '1.0', true );
	/* wp_enqueue_script( 'jquery' ); */
}

add_action( 'comment_form_before', 'urban_square_enqueue_comment_reply_script' );
function urban_square_enqueue_comment_reply_script() {
if ( get_option( 'thread_comments' ) ) { wp_enqueue_script( 'comment-reply' ); }
}

add_filter( 'the_title', 'urban_square_title' );
function urban_square_title( $title ) {
	if ( $title == '' ) {
		return '&rarr;';
	} else {
		return $title;
	}
}

add_filter( 'wp_title', 'urban_square_filter_wp_title' );
function urban_square_filter_wp_title( $title ) {
	return $title . esc_attr( get_bloginfo( 'name' ) );
}

add_action( 'widgets_init', 'urban_square_widgets_init' );
function urban_square_widgets_init() {
	register_sidebar( array (
		'name' => __( 'Sidebar Widget Area', 'urban-square' ),
		'id' => 'primary-widget-area',
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => "</li>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	));
}

function urban_square_custom_pings( $comment ) {
$GLOBALS['comment'] = $comment;
?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>"><?php echo comment_author_link(); ?></li>
<?php 
}

add_filter( 'get_comments_number', 'urban_square_comments_number' );
function urban_square_comments_number( $count ) {
	if ( !is_admin() ) {
		global $id;
		$comments_by_type = &separate_comments( get_comments( 'status=approve&post_id=' . $id ) );
		return count( $comments_by_type['comment'] );
	} else {
		return $count;
	}
}